@@ -1,41 +1,26 @@
 /*
- * Copyright 2014  Martin Gräßlin <mgraesslin@kde.org>
+ * SPDX-FileCopyrightText: 2014 Martin Gräßlin <mgraesslin@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 #ifndef KDECORATION2_DECORATED_CLIENT_H
 #define KDECORATION2_DECORATED_CLIENT_H
 
-#include <kdecoration2/kdecoration2_export.h>
+#include "decoration.h"
 #include "decorationdefines.h"
+#include <kdecoration2/kdecoration2_export.h>
 
+#include <QFont>
+#include <QIcon>
 #include <QObject>
+#include <QPalette>
 #include <QPointer>
 #include <QtGui/qwindowdefs.h>
-#include <QIcon>
-#include <QPalette>
-#include <QFont>
 
 #include <memory>
 
 namespace KDecoration2
 {
-
-class Decoration;
 class DecorationBridge;
 class DecoratedClientPrivate;
 
